@@ -15,29 +15,16 @@
 ** along with this program.  If not, see http://www.gnu.org/licenses.
 */
 
+#include "precompiled.h"
 #include "custombutton.h"
-#include <QPainter>
-#include <QDebug>
-#include <QGraphicsSceneMouseEvent>
 
 //-----------------------------------------------------------------------------
 /**
 ** Constructor.
-**
-** \param strBackground The name of the background image.
-** \param strIcon The name of the icon which is placed on the button.
-** \param iconOffset The icon offset from the center.
 */
-CCustomButton::CCustomButton(const QString& strBackground, const QString& strIcon, QPointF iconOffset) : QObject(NULL), QGraphicsItem()
+CCustomButton::CCustomButton(QObject* pParent) : QObject(pParent), QGraphicsItem()
 {
-    m_pxBackground = QPixmap::fromImage(QImage(strBackground));
-    m_pxIcon = QPixmap::fromImage(QImage(strIcon));
     m_State = State_Normal;
-    m_IconOffset = iconOffset;
-
-#ifndef Q_WS_HILDON
-    setAcceptHoverEvents(true);
-#endif
 }
 
 //-----------------------------------------------------------------------------
@@ -48,15 +35,31 @@ CCustomButton::~CCustomButton()
 {
 }
 
+//-----------------------------------------------------------------------------
+/**
+** Sets the graphics used in the button.
+**
+** \param pxBackground Thebackground image.
+** \param pxIcon The icon which is placed on the button.
+** \param iconOffset The icon offset from the center.
+*/
+void CCustomButton::setGraphics(const QPixmap& pxBackground, const QPixmap& pxIcon, QPointF iconOffset)
+{
+    m_pxBackground = pxBackground;
+    m_pxIcon = pxIcon;
+    m_IconOffset = iconOffset;
+    update();
+}
+
 //-----------------------------------------------------------------------------
 /**
 ** Sets the icon used in the button.
 **
 ** \param strIcon The name of the icon.
 */
-void CCustomButton::setIcon(const QString& strIcon)
+void CCustomButton::setIcon(const QPixmap& pxIcon)
 {
-    m_pxIcon = QPixmap::fromImage(QImage(strIcon));
+    m_pxIcon = pxIcon;
     update();
 }
 
@@ -81,10 +84,13 @@ QRectF CCustomButton::boundingRect() const
 */
 void CCustomButton::paint(QPainter* pPainter, const QStyleOptionGraphicsItem* pOption, QWidget* pWidget)
 {
+    Q_UNUSED(pOption);
+    Q_UNUSED(pWidget);
+
     pPainter->drawPixmap(0, 0, m_pxBackground.width(), m_pxBackground.height(), m_pxBackground);
 
-    QPointF pos((m_pxBackground.width() - m_pxIcon.width() / 3) / 2, (m_pxBackground.height() - m_pxIcon.height()) / 2);
-    pPainter->drawPixmap(pos + m_IconOffset, m_pxIcon, QRectF(m_State * m_pxIcon.width() / 3, 0, m_pxIcon.width() / 3, m_pxIcon.height()));
+    QPointF pos((m_pxBackground.width() - m_pxIcon.width() / 2) / 2, (m_pxBackground.height() - m_pxIcon.height()) / 2);
+    pPainter->drawPixmap(pos + m_IconOffset, m_pxIcon, QRectF(m_State * m_pxIcon.width() / 2, 0, m_pxIcon.width() / 2, m_pxIcon.height()));
 }
 
 //-----------------------------------------------------------------------------
@@ -95,13 +101,15 @@ void CCustomButton::paint(QPainter* pPainter, const QStyleOptionGraphicsItem* pO
 */
 void CCustomButton::mousePressEvent(QGraphicsSceneMouseEvent* pEvent)
 {
+    Q_UNUSED(pEvent);
+
     m_State = State_Pushed;
     update();
 }
 
 //-----------------------------------------------------------------------------
 /**
-** Handler for the mouse release events. Changes the state of the button.
+** Handler for the #include <mouse release events. Changes the state of the button.
 **
 ** \param pEvent The mouse event.
 */
@@ -109,11 +117,7 @@ void CCustomButton::mouseReleaseEvent(QGraphicsSceneMouseEvent* pEvent)
 {
     if (boundingRect().contains(pEvent->pos()))
     {
-#ifndef Q_WS_HILDON
-        m_State = State_Hover;
-#else
         m_State = State_Normal;
-#endif
         emit clicked();
     }
     else
@@ -124,28 +128,4 @@ void CCustomButton::mouseReleaseEvent(QGraphicsSceneMouseEvent* pEvent)
     update();
 }
 
-//-----------------------------------------------------------------------------
-/**
-** Handler for the mouse hover enter events. Changes the state of the button.
-**
-** \param pEvent The mouse event.
-*/
-void CCustomButton::hoverEnterEvent(QGraphicsSceneHoverEvent* pEvent)
-{
-    m_State = State_Hover;
-    update();
-}
-
-//-----------------------------------------------------------------------------
-/**
-** Handler for the mouse hover leave events. Changes the state of the button.
-**
-** \param pEvent The mouse event.
-*/
-void CCustomButton::hoverLeaveEvent(QGraphicsSceneHoverEvent* pEvent)
-{
-    m_State = State_Normal;
-    update();
-}
-
 // EOF
