@@ -15,7 +15,7 @@
 ** along with this program.  If not, see http://www.gnu.org/licenses.
 */
 
-#include <QtGui/QApplication>
+#include "precompiled.h"
 #include "mainwindow.h"
 
 //-----------------------------------------------------------------------------
